==> 2.2.4.tar.gz: test/testmain.dart <==
import 'dart:core';
import 'package:toolbox_indicator_test/api.dart';
import 'package:toolbox_indicator_test/function.dart';
import 'package:toolbox_indicator_test/variables.dart';
import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:geiger_api/geiger_api.dart';
//import 'package:initialize_geiger_data/initialize_geiger_data.dart';

void main() async {

  //final StorageController controller = GenericController('testOwner', DummyMapper('testOwner'));
//  final StorageController controller = GenericController('theOwner',SqliteMapper('./dbFileName.sqlite'));
//Storage.controller = controller;

  final localMaster =
  (await getGeigerApi("", GeigerApi.masterId, Declaration.doShareData))
  !;
  Storage.controller = localMaster.getStorage();

  print(await  Storage.controller!.dump(":"));

  //initializeGeigerData(Storage.geigerIndicatorUUID);
  //await testInitializeGeigerData(Storage.geigerIndicatorUUID,Storage.controller);

  await createLocal();

  await initPlugin();
  await setValueListener();
  await checkExistNodes();

  await getRecommendation();
  await getRisk();

//  if(Storage.getValuePath.isNotEmpty){

  print(Storage.getValuePath.length);

  await getMetrics(Types.users, Storage.userUUID);
  await updateScoreNode(Types.users, Types.geigerScoreUser);
  await updateRecommendationNode(Types.users);

  await getMetrics(Types.devices, Storage.deviceUUID);
  await updateScoreNode(Types.devices, Types.geigerScoreDevice);
  await updateRecommendationNode(Types.devices);

  //await getDevices();
  //await getEmployees();
//  await crtAggregateScore();
//  await updateScoreNode(Types.users, Types.geigerScoreAggregate);
//
//  updateScoreMSENode();



  //await deviceBot('',Storage.deviceUUID);



//  await Listener.sensorsValue.awaitCount(1);


//  }else{
//  print('=======Waiting sensors Values');
//  //Listener.sensorsValue.getNumEvents(1,500);
//
//  var bodys = '{"geigerValue": "32.5", "minValue": "0", "cUUID": "5a6487c7-c1c5-4f28-995e-8805e45bf1a3", "maxValue": "100", "valueType": "double", "mUUID": "123e4567-e89b-42d3-a456-556642440sdk-m01", '
//  '"threatsImpact": "80efffaf-98a1-4e0a-8f5e-gr89388352ph,High;80efffaf-98a1-4e0a-8f5e-gr89388354sp,High;80efffaf-98a1-4e0a-8f5e-th89388365it,High;80efffaf-98a1-4e0a-8f5e-gr89388350ma,Medium;80efffaf-98a1-4e0a-8f5e-gr89388356db,Medium"}';
//  var a = json.decode(bodys.toString());
//
//  await createUserData(a);
//
//  var cbodys = '{"geigerValue": "90.1", "minValue": "0", "cUUID": "5a6487c7-c1c5-4f28-995e-8805e45bf1a3", "maxValue": "100", "valueType": "double", "mUUID": "123e4567-e89b-42d3-a456-556642440sdk-m01", '
//  '"threatsImpact": "80efffaf-98a1-4e0a-8f5e-gr89388352ph,High;80efffaf-98a1-4e0a-8f5e-gr89388354sp,High;80efffaf-98a1-4e0a-8f5e-th89388365it,High;80efffaf-98a1-4e0a-8f5e-gr89388350ma,Medium;80efffaf-98a1-4e0a-8f5e-gr89388356db,Medium"}';
//  var aa = json.decode(cbodys.toString());
//
//  await createDeviceData(aa);

//  await Listener.sensorsValue.getNumEvents(2,1000).whenComplete(() async => await updateData(Listener.sensorsValue.events.iterator));

//  }


}

==> 2.3.1.tar.gz: test/testmain.dart <==
import 'dart:core';
import 'package:toolbox_indicator_test/api.dart';
import 'package:toolbox_indicator_test/function.dart';
import 'package:toolbox_indicator_test/variables.dart';
import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:geiger_api/geiger_api.dart';
//import 'package:initialize_geiger_data/initialize_geiger_data.dart';

void main() async {

  //final StorageController controller = GenericController('testOwner', DummyMapper('testOwner'));

  final StorageController controller = GenericController('test',SqliteMapper('./dbFileName.sqlite'));
  Storage.controller = controller;

//  final localMaster =
//  (await getGeigerApi("", GeigerApi.masterId, Declaration.doNotShareData))
//  !;
//  Storage.controller = localMaster.getStorage();

  print(await  Storage.controller!.dump(':'));

  //initializeGeigerData(Storage.geigerIndicatorUUID);
  //await testInitializeGeigerData(Storage.geigerIndicatorUUID,Storage.controller);

  await createLocal();

  await initPlugin();
  await setValueListener();
  await checkExistNodes();

  await getRecommendation();
  await getRisk();

//  if(Storage.getValuePath.isNotEmpty){

  print(Storage.getValuePath.length);

  await getMetrics(Types.users, Storage.userUUID);
  await updateScoreNode(Types.users, Types.geigerScoreUser);
  await updateRecommendationNode(Types.users);

  await getMetrics(Types.devices, Storage.deviceUUID);
  await updateScoreNode(Types.devices, Types.geigerScoreDevice);
  await updateRecommendationNode(Types.devices);

  //await getDevices();
  //await getEmployees();
//  await crtAggregateScore();
//  await updateScoreNode(Types.users, Types.geigerScoreAggregate);
//
//  updateScoreMSENode();



  //await deviceBot('',Storage.deviceUUID);



//  await Listener.sensorsValue.awaitCount(1);


//  }else{
//  print('=======Waiting sensors Values');
//  //Listener.sensorsValue.getNumEvents(1,500);
//
//  var bodys = '{"geigerValue": "32.5", "minValue": "0", "cUUID": "5a6487c7-c1c5-4f28-995e-8805e45bf1a3", "maxValue": "100", "valueType": "double", "mUUID": "123e4567-e89b-42d3-a456-556642440sdk-m01", '
//  '"threatsImpact": "80efffaf-98a1-4e0a-8f5e-gr89388352ph,High;80efffaf-98a1-4e0a-8f5e-gr89388354sp,High;80efffaf-98a1-4e0a-8f5e-th89388365it,High;80efffaf-98a1-4e0a-8f5e-gr89388350ma,Medium;80efffaf-98a1-4e0a-8f5e-gr89388356db,Medium"}';
//  var a = json.decode(bodys.toString());
//
//  await createUserData(a);
//
//  var cbodys = '{"geigerValue": "90.1", "minValue": "0", "cUUID": "5a6487c7-c1c5-4f28-995e-8805e45bf1a3", "maxValue": "100", "valueType": "double", "mUUID": "123e4567-e89b-42d3-a456-556642440sdk-m01", '
//  '"threatsImpact": "80efffaf-98a1-4e0a-8f5e-gr89388352ph,High;80efffaf-98a1-4e0a-8f5e-gr89388354sp,High;80efffaf-98a1-4e0a-8f5e-th89388365it,High;80efffaf-98a1-4e0a-8f5e-gr89388350ma,Medium;80efffaf-98a1-4e0a-8f5e-gr89388356db,Medium"}';
//  var aa = json.decode(cbodys.toString());
//
//  await createDeviceData(aa);

//  await Listener.sensorsValue.getNumEvents(2,1000).whenComplete(() async => await updateData(Listener.sensorsValue.events.iterator));

//  }


}
